@@ -1,31 +1,35 @@
 ###########################################################################/**
 # @RdocDocumentation toNNN
 # @alias toBMP
+# @alias toEMF
 # @alias toEPS
 # @alias toPDF
 # @alias toPNG
 # @alias toSVG
 # @alias toTIFF
+# @alias toWMF
 #
 # @title "Methods for creating image files of a specific format"
 #
 # \description{
 #  @get "title".
 # }
-# 
+#
 # \usage{
 #   toBMP(name, ..., field=getOption("devEval/args/field", "fullname"))
-#   toEPS(name, ..., field=getOption("devEval/args/field", "fullname"))
+#   toEMF(name, ..., ext="emf", field=getOption("devEval/args/field", "fullname"))
 #   toPDF(name, ..., field=getOption("devEval/args/field", "fullname"))
 #   toPNG(name, ..., field=getOption("devEval/args/field", "fullname"))
 #   toSVG(name, ..., field=getOption("devEval/args/field", "fullname"))
 #   toTIFF(name, ..., field=getOption("devEval/args/field", "fullname"))
+#   toWMF(name, ..., ext="wmf", field=getOption("devEval/args/field", "fullname"))
 # }
 #
 # \arguments{
 #   \item{name}{A @character string specifying the name of the image file.}
 #   \item{...}{Additional arguments passed to @see "devEval", e.g.
 #      \code{tags} and \code{aspectRatio}.}
+#   \item{ext}{A @character string specifying the filename extension.}
 #   \item{field}{Passed to @see "devEval".}
 # }
 #
@@ -45,11 +49,19 @@
 #
 # @keyword device
 # @keyword utilities
-#*/########################################################################### 
+#*/###########################################################################
 toBMP <- function(name, ..., field=getOption("devEval/args/field", "fullname")) {
   devEval(type="bmp", name=name, ..., field=field);
 }
 
+toEMF <- function(name, ..., ext="emf", field=getOption("devEval/args/field", "fullname")) {
+  devEval(type="win.metafile", name=name, ..., ext=ext, field=field);
+}
+
+toWMF <- function(name, ..., ext="wmf", field=getOption("devEval/args/field", "fullname")) {
+  devEval(type="win.metafile", name=name, ..., ext=ext, field=field);
+}
+
 toEPS <- function(name, ..., field=getOption("devEval/args/field", "fullname")) {
   devEval(type="eps", name=name, ..., field=field);
 }
@@ -73,9 +85,11 @@ toTIFF <- function(name, ..., field=getOption("devEval/args/field", "fullname"))
 
 ##############################################################################
 # HISTORY:
+# 2013-07-24
+# o Added toEMF()/toWMF().
 # 2013-02-23
 # o Changed default argument 'field' for toNNN() from "fullname"
-#   to getOption("devEval/args/field", "fullname"). 
+#   to getOption("devEval/args/field", "fullname").
 # 2012-05-01
 # o Renamed Rd to toNNN.
 # 2012-04-27
